<template>
  <span :id="id" :name="field.name+'_show'" class="component-input-span">
    <template
      v-if="field.displayType == Constant.PermissionType_HIDDEN || field.textType.toLowerCase() == 'hidden'"
    >
      <!-- 隐藏 TODO:注意，隐藏时不应该有hidden的field存在，有安全问题，以后要改过来：Jarod -->
      <input type="hidden" v-model="field.value" />
      <mt-cell :title="field.discript?field.discript : field.name" v-if="field.mobile && field.hiddenValue">
        <span>{{field.hiddenValue}}</span>
      </mt-cell>
    </template>

    <!-- 只读 -->
    <template v-else-if="field.textType.toLowerCase() == 'readonly' || field.displayType == Constant.PermissionType_READONLY || field.displayType == Constant.PermissionType_DISABLED">
       <!-- 只读（文本模式） -->
      <template v-if="field.readOnlyShowValOnly">
        <div class="select" v-if="field.mobile">
          <a class="mint-cell">  
            <div class="mint-cell-wrapper">
              <div class="mint-cell-title">
                <span class="mint-cell-text">
                  {{field.discript?field.discript:field.name}}
                  <span style="color:red" v-if="field.essential || field.instantValidate || (field.validateLibs && field.validateLibs.indexOf('checkEmpty_system') > 0)">*</span>  
                </span> 
              </div> 
              <div class="mint-cell-value">
                <span style = "color: #888;">{{field.option}}</span>
              </div> 
            </div> 
          </a>
        </div>
      </template>
      <template v-else>
        <div class="select" @click="popupVisible = true" v-if="field.mobile">
          <a class="mint-cell">  
            <div class="mint-cell-wrapper">
              <div class="mint-cell-title">
                <span class="mint-cell-text">
                  {{field.discript?field.discript:field.name}}
                  <span style="color:red" v-if="field.essential || field.instantValidate || (field.validateLibs && field.validateLibs.indexOf('checkEmpty_system') > 0)">*</span>  
                </span> 
              </div> 
              <div class="mint-cell-value">
                <span style = "color: #888;">{{field.option}}</span>
              </div> 
            </div> 
          </a>
        </div>
      </template>
    </template>
    <template v-else-if="field.displayType == Constant.PermissionType_MODIFY">
      <!-- 可编辑 -->
      <div class="select" :class="{textareaCheck: isActive }" @click="popupVisible = true" v-if="field.mobile">
        <a class="mint-cell">
          <span class="mint-cell-mask"></span> 
          <div class="mint-cell-left"></div> 
          <div class="mint-cell-wrapper">
            <div class="mint-cell-title">
              <!----> 
              <span class="mint-cell-text">
                {{field.discript?field.discript:field.name}}
                <span style="color:red" v-if="field.essential || field.instantValidate || (field.validateLibs && field.validateLibs.indexOf('checkEmpty_system') > 0)">*</span>
              </span> 
              <!---->
            </div> 
            <div class="mint-cell-value is-link">
              <span>{{field.option?field.option: $t('please_choose')}}</span>
            </div> 
            <i class="mint-cell-allow-right"></i>
          </div> 
          <div class="mint-cell-right"></div>
        </a>
        <div class="tips" v-show="isActive">
          {{errorMessage}}
        </div>
      </div>
      <mt-popup v-model="popupVisible" position="bottom">
        <mt-picker 
          :slots="field.slots" 
          :show-toolbar="true"  
          ref="picker" 
          value-key="value"
        >
          <div class="btns-wrap">
            <span @click="handleCancel">{{$t('cancel')}}</span>
            <span @click="handleConfirm">{{$t('verify')}}</span>
          </div>
        </mt-picker>
      </mt-popup>
    </template>
  </span>
</template>

<script>
import Constant from "@/Constant.js"
import controlHidden from "@/assets/js/controlHidden.js"
export default {
  name: "o-dept-select",
  props: ["id"],
  computed: {
    field: function() {
      let allData = this.$parent.findField(this.id);
      if(allData.discript) {//识别控件描述最后一个字符为*时，*变红
        if(allData.discript.charAt(allData.discript.length - 1) == "*") {
          allData.discript = allData.discript.replace(/(\s|\*)+$/g, '');
          allData.essential = true;
        }
      }
      let currentVal = allData.value;
      let slot = [];
      //针对第一条数据的值为空时
      if(allData.options && allData.options.length > 0 && !allData.options[0].option && !allData.options[0].value){
        allData.options[0].option = " ";
        allData.options[0].value = " ";
      }
      
      //转化为mintui能接受的形式
      if(allData.options) {
        for(let j=0; j<allData.options.length; j++) {
          let temp = allData.options[j].option;
          allData.options[j].option = allData.options[j].value;
          allData.options[j].value = temp;
        }
        for(let i=0; i < allData.options.length; i++) {
          if(allData.options[i].option == currentVal) {
            //allData.value = allData.options[i].value;
            allData.option = allData.options[i].value;
          }
        }

        let value = {
          values: allData.options
        }; 
        slot.push(value);
        allData.slots = slot;
      }
      
      delete allData.options;

      return allData;
    }
  },
  mounted(){
    this.$nextTick(()=>{
      let field = this.field;
      if(field.isHideType) {
        let id = this.id,
          formShowType = field.formShowType;
        controlHidden({id, field, formShowType})
      }
    })
  },
  methods: {
    handleCancel() {
      this.popupVisible = false;
    },
    handleConfirm () {
      let field = this.field;
      this.field.value = this.$refs.picker.getValues()[0].option;
      this.field.option = this.$refs.picker.getValues()[0].value;
      this.popupVisible = false;
      if (field.refreshOnChanged) {//判断是否需要刷新
        // this.$parent.refresh(this.id);
        let havePar = false;
        let par  = '';
        while(!havePar) {
          par = par + '.$parent';
          let url = 'this' + par + '.refresh';
          if(eval(url)) {
            let path = url + '(' + "'"+ this.id +"'" + ')';
            eval(path);
            break
          }
        }
      }
      if(field.instantValidate) {
        this.isFieldClear = false;
        let value = true;
        let formData = this.$parent.checkData(value);
        this.$api.formValidation(
          this.$root.appid, 
          formData,
          {
            onSucess: response => {
              if(response.data.errcode == 4001) {
                if(response.data.errors && response.data.errors.length > 0) {
                  let arr = response.data.errors;
                  for(let i=0; i<arr.length; i++) {
                    if(this.field.name == arr[i].field) {
                      this.isActive = true;
                      this.errorMessage = arr[i].errmsg
                      return;
                    }else {
                      this.isActive = false;
                      this.errorMessage = '';
                    }
                  }
                }
              }else if(response.data.errcode == 0) {
                this.isActive = false;
              }
            }
          }
        )
      } 
    },
  },
  data: function() {
    return { 
      isActive: false,
      errorMessage:'',
      Constant, 
      selectedOption: {},
      popupVisible:false,
      slots: [
        {
          values: [
            
          ]
        }
      ] 
    };
  }
};
</script>